.. image:: https://travis-ci.org/timcera/tsgettoolbox.svg?branch=master
    :target: https://travis-ci.org/timcera/tsgettoolbox
    :height: 20

.. image:: https://coveralls.io/repos/timcera/tsgettoolbox/badge.png?branch=master
    :target: https://coveralls.io/r/timcera/tsgettoolbox?branch=master
    :height: 20

.. image:: https://img.shields.io/pypi/v/tsgettoolbox.svg
    :alt: Latest release
    :target: https://pypi.python.org/pypi/tsgettoolbox

.. image:: http://img.shields.io/badge/license-BSD-lightgrey.svg
    :alt: BSD-3 clause license
    :target: https://pypi.python.org/pypi/tsgettoolbox/

.. image:: http://img.shields.io/pypi/dd/tsgettoolbox.svg
    :alt: tsgettoolbox downloads
    :target: https://pypi.python.org/pypi/tsgettoolbox/
